within ;
package Guyton72

  package Library
    connector SoluteFlow
      Real nconc
        "normalized concentration, concentration rate on normal concentration";
      flow Real nflow
        "normalized solute flow, solute flow rate on normal solute flow";
    annotation (
        defaultComponentName="flow",
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[1, 1],
          component=[20, 20],
          scale=0.2),
        Icon(coordinateSystem(extent=[-100, -100; 100, 100]), Polygon(points=[-50,-5;
                0,40; 50,-5; 0,-51; -50,-5],            style(
              color=74,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0}))),
        Diagram(Polygon(points=[-21,-3; 5,23; 31,-3; 5,-29; -21,-3],   style(
              color=74,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0})), Text(
            extent=[-105,-38; 115,-83],
            string="%name",
            style(color=0, rgbcolor={0,0,0}))),
        Documentation(info="<html>
<p>
Connector with one flow signal of type Real.
</p>
</html>"));
    end SoluteFlow;

    connector PositiveSoluteFlow
      extends Guyton72.Library.SoluteFlow;
      annotation (
        defaultComponentName="flow",
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[1, 1],
          component=[20, 20],
          scale=0.2),
        Icon(coordinateSystem(extent=[-100, -100; 100, 100]), Polygon(points=[-50,63;
                50,18; 50,-22; -50,-78; -50,63],        style(
              color=74,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0}))),
        Diagram(Polygon(points=[-23,40; 32,11; 31,-22; -23,-49; -23,40],
                                                                       style(
              color=74,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0})), Text(
            extent=[-120, 105; 100, 60],
            string="%name",
            style(color=0, rgbcolor={0,0,0}))),
        Documentation(info="<html>
<p>
Connector with one flow signal of type Real.
</p>
</html>"));
    end PositiveSoluteFlow;

    connector NegativeSoluteFlow
      extends Guyton72.Library.SoluteFlow;
      annotation (
        defaultComponentName="flow",
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[1, 1],
          component=[20, 20],
          scale=0.2),
        Icon(coordinateSystem(extent=[-100, -100; 100, 100]), Polygon(points=[-49,57;
                52,17; 52,-23; -49,-73; -49,57],        style(
              color=7,
              rgbcolor={0,0,0},
              fillColor=255,
              rgbfillColor={255,255,255}))),
        Diagram(Polygon(points=[0, 25; 50, 10; 50, -10; 0, -25; 0, 25],style(
              color=74,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255})), Text(
            extent=[-120, 105; 100, 60],
            string="%name",
            style(color=0, rgbcolor={0,0,0}))),
        Documentation(info="<html>
<p>
Connector with one flow signal of type Real.
</p>
</html>"));
    end NegativeSoluteFlow;

    model Source
      extends Modelica.Blocks.Interfaces.BlockIcon;

      Guyton72.Library.NegativeSoluteFlow q_out 
        annotation (extent=[90, -10; 110, 10]);
      Modelica.Blocks.Interfaces.RealInput soluteFlow "solute flow" 
        annotation (extent=[-10, 90; 10, 110], rotation=-90);
      parameter Real normal_solute_flow "normal solute flow";
    equation
      q_out.nflow = -soluteFlow/normal_solute_flow;
    end Source;

    partial model BaseFlowBlock
      extends Modelica.Blocks.Interfaces.BlockIcon;
      Guyton72.Library.PositiveSoluteFlow q_in 
        annotation (extent=[-110, -10; -90, 10]);
      Guyton72.Library.NegativeSoluteFlow q_out 
        annotation (extent=[90, -10; 110, 10]);
    end BaseFlowBlock;

    model SoluteFlux
      extends BaseFlowBlock;
      parameter Real nForwardFlowCoef
        "forward flow coef, first nconc to nflow multiplier";
      parameter Real nBackwardFlowCoef
        "backward flow coef, second nconc to nflow multiplier";
    equation
      q_in.nflow + q_out.nflow = 0;
      q_in.nflow = nForwardFlowCoef*q_in.nconc - nBackwardFlowCoef*q_out.nconc;
    end SoluteFlux;

    model Clearance
      extends Modelica.Blocks.Interfaces.BlockIcon;

      Guyton72.Library.PositiveSoluteFlow q_in 
        annotation (extent=[-110, -10; -90, 10]);
      parameter Real nconc_to_nflow_coef = 0.1;
    equation
      q_in.nflow = q_in.nconc * nconc_to_nflow_coef;
    end Clearance;

    model BasePool
      extends Modelica.Blocks.Interfaces.BlockIcon;
      Guyton72.Library.PositiveSoluteFlow q_in 
                            annotation (extent=[-10, -110; 10, -90], Placement(
            transformation(extent={{-110,-10},{-90,10}})));
      Guyton72.Library.NegativeSoluteFlow q_out 
                             annotation (extent=[-10, -110; 10, -90], Placement(
            transformation(extent={{90,-10},{110,10}})));
      Modelica.Blocks.Interfaces.RealOutput nconc
        "normalized concentration, concentration rate on normal concentration" 
        annotation (extent=[-10,90; 10, 110],rotation=90);
    initial equation
      nconc = 1;
    equation
      der(nconc) = q_in.nflow + q_out.nflow;
      q_in.nconc = nconc;
      q_out.nconc = nconc;
      annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                -100},{100,100}}), graphics));
    end BasePool;

    model SecretionAndClearence
      extends Modelica.Blocks.Interfaces.SISO;
      parameter Real normal_secretion_flow = 1;
      parameter Real clearance_nconc_to_nflow_coef = 1;
      parameter Real base_effect= 1;
      parameter Real effect_difference_multiplier= 1;
      parameter Real effect_mass_exponent_multiplier= 1;

      Source secretion(normal_solute_flow=
            normal_secretion_flow) 
        annotation (extent=[-62,-24; -42,-4]);
      Guyton72.Library.NormalizedConcentrationToEffect nconcToEffect(
        base_effect=base_effect,
        mass_exponent_multiplier=effect_mass_exponent_multiplier,
        difference_multiplier=effect_difference_multiplier) 
        annotation (extent=[8,10; 28,22]);
      BasePool basePool 
        annotation (Placement(transformation(extent={{-30,-24},{-10,-4}})));
      annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                -100},{100,100}}), graphics));
      Clearance clearance(nconc_to_nflow_coef=clearance_nconc_to_nflow_coef) 
        annotation (Placement(transformation(extent={{6,-24},{26,-4}})));
    equation
      connect(secretion.soluteFlow, u) 
                                   annotation (points=[-52,-4; -52,0; -120,0],
          style(color=74, rgbcolor={0,0,127}));
      connect(nconcToEffect.y, y) 
                                 annotation (points=[29,16; 62.5,16; 62.5,0;
            110,0],
                style(color=74, rgbcolor={0,0,127}));
      connect(y, y) annotation (points=[110,0; 108,0; 108,0; 110,0], style(
            color=74, rgbcolor={0,0,127}));
      connect(secretion.q_out, basePool.q_in) annotation (Line(
          points={{-42,-14},{-30,-14}},
          color={0,0,0},
          smooth=Smooth.None));
      connect(basePool.nconc, nconcToEffect.u) 
                                              annotation (Line(
          points={{-20,-4},{-20,16},{6,16}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(basePool.q_out, clearance.q_in) annotation (Line(
          points={{-10,-14},{6,-14}},
          color={0,0,0},
          smooth=Smooth.None));
    end SecretionAndClearence;

    block NormalizedConcentrationToEffect
      extends Modelica.Blocks.Interfaces.PartialConversionBlock;
      parameter Real base_effect= 1;
      parameter Real difference_multiplier= 1;
      parameter Real mass_exponent_multiplier= 1;
    equation
      y = base_effect - difference_multiplier/(10^(u*mass_exponent_multiplier));
    end NormalizedConcentrationToEffect;

    package Organs     
    end Organs;

    model BasePoolWithOneFlow
      extends Modelica.Blocks.Interfaces.BlockIcon;
      Guyton72.Library.PositiveSoluteFlow q 
                 annotation (extent=[-10, -110; 10, -90], rotation=90);
      Modelica.Blocks.Interfaces.RealOutput nconc
        "normalized concentration, concentration rate on normal concentration" 
        annotation (extent=[90, -10; 110, 10], Diagram(coordinateSystem(
              preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics));
    initial equation
      q.nconc = 1;
    equation
      der(q.nconc) = q.nflow;
      nconc = q.nconc;
    end BasePoolWithOneFlow;

    model SecretionAndClearence2
      extends Modelica.Blocks.Interfaces.SISO;
      parameter Real normal_secretion_flow = 1;
      parameter Real clearance_coef = 1;
      parameter Real initial_state = 1;

      parameter Real base_effect= 1;
      parameter Real effect_difference_multiplier= 1;
      parameter Real effect_mass_exponent_multiplier= 1;

      Source secretion(normal_solute_flow=
            normal_secretion_flow) 
        annotation (extent=[-62,-24; -42,-4]);
      Guyton72.Library.SoluteFlux soluteFlux(nForwardFlowCoef=clearance_coef, nBackwardFlowCoef=0) 
        annotation (extent=[2,-24; 22,-4]);
      Guyton72.Library.NormalizedConcentrationToEffect nconcToEffect(
        base_effect=base_effect,
        mass_exponent_multiplier=effect_mass_exponent_multiplier,
        difference_multiplier=effect_difference_multiplier) 
        annotation (extent=[8,10; 28,22]);
      Sink sink 
        annotation (Placement(transformation(extent={{34,-24},{54,-4}})));
      annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                -100},{100,100}}),      graphics));
      BasePoolWithOneFlow basePool 
        annotation (Placement(transformation(extent={{-32,6},{-12,26}})));
    equation
      connect(secretion.soluteFlow, u) 
                                   annotation (points=[-52,-4; -52,0; -120,0],
          style(color=74, rgbcolor={0,0,127}));
      connect(nconcToEffect.y, y) 
                                 annotation (points=[29,16; 62.5,16; 62.5,0;
            110,0],
                style(color=74, rgbcolor={0,0,127}));
      connect(y, y) annotation (points=[110,0; 108,0; 108,0; 110,0], style(
            color=74, rgbcolor={0,0,127}));
      connect(soluteFlux.q_out, sink.q_in) annotation (Line(
          points={{22,-14},{34,-14}},
          color={0,0,0},
          smooth=Smooth.None));
      connect(secretion.q_out, basePool.q) annotation (Line(
          points={{-42,-14},{-22,-14},{-22,6}},
          color={0,0,0},
          smooth=Smooth.None));
      connect(soluteFlux.q_in, basePool.q) annotation (Line(
          points={{2,-14},{-22,-14},{-22,6}},
          color={0,0,0},
          smooth=Smooth.None));
      connect(basePool.nconc, nconcToEffect.u) annotation (Line(
          points={{-12,16},{6,16}},
          color={0,0,127},
          smooth=Smooth.None));
    end SecretionAndClearence2;

    model Sink
      extends Modelica.Blocks.Interfaces.BlockIcon;

      Guyton72.Library.PositiveSoluteFlow q_in 
        annotation (extent=[-110, -10; -90, 10]);
    equation
      q_in.nconc = 0;
    end Sink;

    block Curve
      extends Modelica.Blocks.Interfaces.SISO;
      parameter Real[1, :] x = [0,1];
      parameter Real[1, :] yValues = [0,1];
    protected
      Real[1, size(x,2)] slope;
      Integer index;
    algorithm
        slope[1,1] :=(x[1, 2] - x[1, 1])/(yValues[1, 2] - yValues[1, 1]);
        index :=2;
        while (index<size(x,2)) loop
            slope[1,index] :=(x[1, index + 1] - x[1, index - 1])/(yValues[1, index
           + 1] - yValues[1, index - 1]);
            index:=index+1;
        end while;
        slope[1,size(x,2)] :=(x[1, size(x, 2)] - x[1, size(x, 2) - 1])/(yValues[1,
        size(x, 2)] - yValues[1, size(x, 2) - 1]);

        y :=SplineSlope(
        x,
        yValues,
        slope,
        u);

    end Curve;

    function SplineSlope

      input Real[1, :] x;
      input Real[1, :] y;
      input Real[1,:] slope;
      input Real xVal;

      output Real yVal;

    protected
    Integer index;
    Real a1;
    Real a2;
    Real a3;
    Real a4;
    Real x1;
    Real x2;

    Real y1;
    Real y2;
    Real slope1;
    Real slope2;

    algorithm
        // Najdi interval, ve kterem se nachazi xVal

        if (xVal<= x[1,1]) then

          yVal :=(xVal)*slope[1,1] + y[1,1]- x[1,1]*slope[1,1];

        elseif (xVal>=x[1,end]) then

         yVal :=(xVal)*slope[1,end] + y[1,end]-(x[1,end]*slope[1,end]);

        else
          index :=1;
          while ( xVal>x[1,index] and index<=size(x,2)) loop
            index:=index+1;
          end while;

          x1:=x[1,index-1];
          x2:=x[1,index];
          y1:=y[1,index-1];
          y2:=y[1,index];
          slope1:=slope[1,index-1];
          slope2:=slope[1,index];

          a1:=-(-x2*slope2 - x2*slope1 + slope2*x1 + slope1*x1 + 2*y2 - 2*y1)/(x2 - x1)^3;
          a2:=(-x2^2*slope2-2*x2^2*slope1-3*x2*y1+x2*slope1*x1+3*x2*y2-x2*slope2*x1-3*y1*x1+slope1*x1^2+3*y2*x1+2*slope2*x1^2)/(x2-x1)^3;
          a3:=-(-slope1*x2^3-2*x2^2*slope2*x1-x2^2*slope1*x1+x2*slope2*x1^2+2*x2*slope1*x1^2+6*x2*x1*y2-6*x2*x1*y1+slope2*x1^3)/(x2-x1)^3;
          a4:=(-slope1*x2^3*x1+y1*x2^3-slope2*x1^2*x2^2+slope1*x1^2*x2^2-3*y1*x2^2*x1+3*y2*x1^2*x2+slope2*x1^3*x2-y2*x1^3)/(x2-x1)^3;

          yVal :=a1*(xVal)^3 + a2*(xVal)^2 + a3*(xVal) + a4;

        end if;

    end SplineSlope;

    function Spline
      input Real u;
      input Real[1, :] x = [0,1];
      input Real[1, :] yValues = [0,1];
      output Real y;
    protected
      Real[1, size(x,2)] slope;
      Integer index;
    algorithm
        slope[1,1] :=(x[1, 2] - x[1, 1])/(yValues[1, 2] - yValues[1, 1]);
        index :=2;
        while (index<size(x,2)) loop
            slope[1,index] :=(x[1, index + 1] - x[1, index - 1])/(yValues[1, index
           + 1] - yValues[1, index - 1]);
            index:=index+1;
        end while;
        slope[1,size(x,2)] :=(x[1, size(x, 2)] - x[1, size(x, 2) - 1])/(yValues[1,
        size(x, 2)] - yValues[1, size(x, 2) - 1]);

        y :=SplineSlope(
        x,
        yValues,
        slope,
        u);

    end Spline;
  end Library;

  package Hormones
    package ADH

      block OsmEffect
        extends Modelica.Blocks.Interfaces.SISO;
        parameter Real CNZ;
        parameter Real CNR;
      equation
        y = CNZ*(u - CNR);
      end OsmEffect;

      model PressureEffect
          extends Modelica.Blocks.Interfaces.SISO;
        Real AHY;
      initial equation
        AHY = 0;
      equation
        y = u*2 - AHY;
        der(AHY) = y*0.0007;
      end PressureEffect;

      block NeuralEffect
        extends Modelica.Blocks.Interfaces.SISO;
      equation
        y = u - 1;
      end NeuralEffect;

      model ADH
        extends Modelica.Blocks.Interfaces.BlockIcon;
        OsmEffect osmEffect annotation (extent=[-78, 24; -58, 44]);
        PressureEffect pressureEffect annotation (extent=[-78, -10; -58, 10]);
        NeuralEffect neuralEffect annotation (extent=[-78, -46; -58, -26]);
        Modelica.Blocks.Math.Add3 add3_1(k3=-1) 
          annotation (extent=[-38, -6; -26, 8]);
        annotation (Diagram, Icon);
        Modelica.Blocks.Interfaces.RealInput CNA
          "extracellular sodium concentration" 
          annotation (extent=[-132, 16; -92, 56]);
        Modelica.Blocks.Interfaces.RealInput AU
          "overall activity of autonomic system, ratio to normal" 
          annotation (extent=[-132, -20; -92, 20]);
        Modelica.Blocks.Interfaces.RealInput PRA "right atrial pressure" 
          annotation (extent=[-132, -56; -92, -16]);
        Modelica.Blocks.Interfaces.RealOutput AHM
          "antidiuretic hormone multiplier, ratio of normal effect" 
          annotation (extent=[94, -2; 114, 18]);
        Library.SecretionAndClearence secretionAndClearence(
          clearance_nconc_to_nflow_coef=0.14,
          base_effect=6,
          effect_difference_multiplier=6,
          normal_secretion_flow=3,
          effect_mass_exponent_multiplier=0.0785/0.14) 
          annotation (extent=[14,-2; 34,18], Placement(transformation(extent={{
                  12,-2},{32,18}})));
      equation
        connect(osmEffect.y, add3_1.u1) annotation (points=[-57,34; -48,34; -48,
              6.6; -39.2,6.6],       style(color=74, rgbcolor={0,0,127}));
        connect(pressureEffect.y, add3_1.u2) annotation (points=[-57,0; -48,0;
              -48,1; -39.2,1],   style(color=74, rgbcolor={0,0,127}));
        connect(neuralEffect.y, add3_1.u3) annotation (points=[-57, -36; -48,
              -36; -48, -4.6; -39.2, -4.6], style(color=74, rgbcolor={0,0,127}));
        connect(osmEffect.u, CNA) 
                                annotation (points=[-80, 34; -92, 34; -92, 36;
              -112, 36], style(color=74, rgbcolor={0,0,127}));
        connect(pressureEffect.u,AU)  annotation (points=[-80, 0; -112, 0],
            style(color=74, rgbcolor={0,0,127}));
        connect(neuralEffect.u, PRA) 
                                    annotation (points=[-80, -36; -112, -36],
            style(color=74, rgbcolor={0,0,127}));
        connect(add3_1.y, secretionAndClearence.u) annotation (points=[-25.4,1;
              -13.7,1; -13.7,8; 12,8], style(color=74, rgbcolor={0,0,127}));
        connect(secretionAndClearence.y, AHM) annotation (points=[35,8; 104,8],
            style(color=74, rgbcolor={0,0,127}));
      end ADH;
    end ADH;

    package Aldosterone
      block AngiotensinEffect
        extends Modelica.Blocks.Interfaces.SISO;
        annotation (Diagram);
      equation
       y = u;
      end AngiotensinEffect;

      block PressureEffect
        extends Guyton72.Library.Curve(x=[0,30,60,100,160,400],yValues=[7,6.25,3,1,0.15,0.05]);

      end PressureEffect;

      block NatruimAndPotasiumEffect
        extends Modelica.Blocks.Interfaces.SI2SO;
      protected
        Real tmp;
      equation
        tmp = (u1/(0.00352*u2)) - 9;
        y = if tmp<0 then 0 else tmp;
      end NatruimAndPotasiumEffect;

      model Aldosterone
       extends Modelica.Blocks.Interfaces.BlockIcon;
        AngiotensinEffect angiotensinEffect annotation (extent=[-88,58; -68,78]);
        PressureEffect pressureEffect annotation (extent=[-86,28; -66,48]);
        NatruimAndPotasiumEffect natruimAndPotasiumEffect 
          annotation (extent=[-86,-8; -66,12]);
        Modelica.Blocks.Math.Product product 
          annotation (extent=[-48,56; -40,64]);
        Modelica.Blocks.Math.Product product1 
          annotation (extent=[-22,38; -14,46]);
        annotation (Diagram);
        Modelica.Blocks.Interfaces.RealInput ANM
          "angiotensin multiplier effect on vascular resistance, ratio to normal"
          annotation (extent=[-134,48; -94,88]);
        Modelica.Blocks.Interfaces.RealInput PA "aortic pressure" 
          annotation (extent=[-136,18; -96,58]);
        Modelica.Blocks.Interfaces.RealInput CKE
          "extracellular potassium concentration" 
          annotation (extent=[-132,-18; -92,22]);
        Modelica.Blocks.Interfaces.RealOutput AM
          "aldosterone multiplier, ratio to normal effect" 
          annotation (extent=[90,12; 110,32]);
        Modelica.Blocks.Interfaces.RealInput CNA
          "extracellular sodium concentration" 
          annotation (extent=[-134,-50; -94,-10]);
        Library.SecretionAndClearence secretionAndClearence(
          clearance_nconc_to_nflow_coef=1/60,
          base_effect=20.039,
          effect_difference_multiplier=19.8,
          effect_mass_exponent_multiplier=-0.017*60) 
          annotation (extent=[18,12; 38,32]);
      equation
        connect(product.y, product1.u1) annotation (points=[-39.6,60; -28,60;
              -28,44.4; -22.8,44.4],
                                   style(color=74, rgbcolor={0,0,127}));
        connect(angiotensinEffect.y, product.u1) annotation (points=[-67,68;
              -58,68; -58,62.4; -48.8,62.4],
                                         style(color=74, rgbcolor={0,0,127}));
        connect(pressureEffect.y, product.u2) annotation (points=[-65,38; -56,
              38; -56,57.6; -48.8,57.6],
                                     style(color=74, rgbcolor={0,0,127}));
        connect(natruimAndPotasiumEffect.y, product1.u2) annotation (points=[-65,2;
              -44.5,2; -44.5,39.6; -22.8,39.6],      style(color=74, rgbcolor={
                0,0,127}));
        connect(angiotensinEffect.u, ANM) annotation (points=[-90,68; -114,68],
            style(color=74, rgbcolor={0,0,127}));
        connect(pressureEffect.u, PA) annotation (points=[-88,38; -116,38],
            style(color=74, rgbcolor={0,0,127}));
        connect(natruimAndPotasiumEffect.u1, CKE) annotation (points=[-88,8;
              -98,8; -98,2; -112,2], style(color=74, rgbcolor={0,0,127}));
        connect(natruimAndPotasiumEffect.u2, CNA) annotation (points=[-88,-4;
              -98,-4; -98,-30; -114,-30], style(color=74, rgbcolor={0,0,127}));
        connect(product1.y, secretionAndClearence.u) annotation (points=[-13.6,42; 6,
              42; 6,22; 16,22], style(color=74, rgbcolor={0,0,127}));
        connect(secretionAndClearence.y, AM) annotation (points=[39,22; 100,22],
            style(color=74, rgbcolor={0,0,127}));
      end Aldosterone;
    end Aldosterone;

    package Angiotensin
      block RenalEffect
        extends Modelica.Blocks.Interfaces.SI2SO;
      equation
        y = u1*(1.2/u2)^3;
      end RenalEffect;

      block OsmEffect
        extends Modelica.Blocks.Interfaces.SISO;
        Modelica.Blocks.Interfaces.RealOutput CNE
          "Connector of Real output signal" 
          annotation (extent=[-10,-108; 10,-88], rotation = -90);
      protected
       Real tmp;
      equation
        tmp = (152-u);
        CNE = if tmp>1 then 1 else tmp;
        y = 0.1 * CNE;
        annotation (Diagram);
      end OsmEffect;

      model Angiotensin
       extends Modelica.Blocks.Interfaces.BlockIcon;
        RenalEffect renalEffect annotation (extent=[-78,22; -58,42]);
        OsmEffect osmEffect annotation (extent=[-78,-16; -58,4]);
        Modelica.Blocks.Math.Product product annotation (extent=[-44,8; -32,22]);
        annotation (Diagram);
        Modelica.Blocks.Interfaces.RealOutput ANM 
                                                annotation (extent=[90,-8; 110,12]);
        Modelica.Blocks.Interfaces.RealInput REK 
                                               annotation (extent=[-128,28; -88,68]);
        Modelica.Blocks.Interfaces.RealInput RFN 
                                                annotation (extent=[-128,0; -88,40]);
        Modelica.Blocks.Interfaces.RealInput CNA 
          annotation (extent=[-132,-50; -92,-10]);
        Modelica.Blocks.Interfaces.RealOutput CNE 
                                                annotation (extent=[90,-74; 110,
              -54]);
        Library.SecretionAndClearence secretionAndClearence(
          base_effect=4,
          effect_difference_multiplier=3.3,
          effect_mass_exponent_multiplier=0.042,
          normal_secretion_flow=15,
          clearance_nconc_to_nflow_coef=1/15) 
          annotation (extent=[-2,-8; 18,12]);
        Modelica.Blocks.Nonlinear.Limiter limiter(
          uMin=0.7,
          limitsAtInit=true,
          uMax=10000000)     annotation (extent=[42,-8; 62,12]);
      equation
        connect(renalEffect.y, product.u1) annotation (points=[-57,32; -50,32; -50,
              19.2; -45.2,19.2], style(color=74, rgbcolor={0,0,127}));
        connect(osmEffect.y, product.u2) annotation (points=[-57,-6; -50,-6; -50,10.8;
              -45.2,10.8], style(color=74, rgbcolor={0,0,127}));
        connect(renalEffect.u1, REK) 
                                   annotation (points=[-80,38; -90,38; -90,48; -108,
              48], style(color=74, rgbcolor={0,0,127}));
        connect(renalEffect.u2, RFN) 
                                    annotation (points=[-80,26; -90,26; -90,20; -108,
              20], style(color=74, rgbcolor={0,0,127}));
        connect(osmEffect.u, CNA) 
                                 annotation (points=[-80,-6; -92,-6; -92,-30; -112,
              -30], style(color=74, rgbcolor={0,0,127}));
        connect(osmEffect.CNE, CNE) annotation (points=[-68,-15.8; -68,-64; 100,
              -64], style(color=74, rgbcolor={0,0,127}));
        connect(product.y, secretionAndClearence.u) annotation (points=[-31.4,
              15; -17.7,15; -17.7,2; -4,2], style(color=74, rgbcolor={0,0,127}));
        connect(secretionAndClearence.y, limiter.u) annotation (points=[19,2;
              40,2], style(color=74, rgbcolor={0,0,127}));
        connect(limiter.y, ANM) annotation (points=[63,2; 100,2], style(color=
                74, rgbcolor={0,0,127}));
      end Angiotensin;
    end Angiotensin;

    model Hormones
      extends Modelica.Blocks.Interfaces.BlockIcon;
      ADH.ADH vasopressin annotation (extent=[-2,44; 18,64], Placement(
            transformation(extent={{-4,60},{16,80}})));
      Aldosterone.Aldosterone aldosterone annotation (extent=[20,-32; 40,-12],
          Placement(transformation(extent={{20,-48},{40,-28}})));
      Angiotensin.Angiotensin angiotensin annotation (extent=[-28,12; -8,32],
          Placement(transformation(extent={{-20,-4},{0,16}})));
      annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                -100},{100,100}}),      graphics), Icon(graphics));
      Interfaces.FromNerves fromNerves 
        annotation (Placement(transformation(extent={{-78,56},{-58,76}})));
      Interfaces.FromFluidVolumes fromFluidVolumes 
        annotation (Placement(transformation(extent={{-78,-74},{-58,-54}})));
      Interfaces.FromCardiovascularSystem fromCardiovascularSystem 
        annotation (Placement(transformation(extent={{-78,4},{-58,24}})));
      Interfaces.toHormones toHormones 
        annotation (Placement(transformation(extent={{58,-4},{70,36}})));
      Interfaces.HormonesOuput hormones annotation (Placement(transformation(
              extent={{68,-6},{108,36}}), iconTransformation(extent={{82,4},{
                102,26}})));
      CardiovascularSystem.Interfaces.CardiovascularSystemInput cardiovascular 
        annotation (Placement(transformation(extent={{-112,-8},{-72,32}}),
            iconTransformation(extent={{-102,2},{-82,22}})));
      FluidVolumes.Interfaces.FluidVolumesInput fluidVolumes annotation (
          Placement(transformation(extent={{-110,-90},{-70,-50}}),
            iconTransformation(extent={{-108,-54},{-88,-34}})));
      Nerves.Interfaces.NervesInput nerves annotation (Placement(transformation(
              extent={{-110,46},{-70,86}}), iconTransformation(extent={{-112,56},
                {-92,76}})));
    equation
      connect(aldosterone.ANM, angiotensin.ANM) annotation (Line(
          points={{18.6,-31.2},{12,-30},{12,6.2},{0,6.2}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(toHormones.hormones, hormones) annotation (Line(
          points={{65.08,16},{76.9,16},{76.9,15},{88,15}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(toHormones.AM, aldosterone.AM) annotation (Line(
          points={{62.38,24.6},{62.38,24.3},{40,24.3},{40,-35.8}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(toHormones.AHM, vasopressin.AHM) annotation (Line(
          points={{62.38,12.2},{60,10},{34,10},{34,70.8},{16.4,70.8}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(toHormones.ANM, angiotensin.ANM) annotation (Line(
          points={{62.26,5.4},{12,5.4},{12,6.2},{0,6.2}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(toHormones.CNE, angiotensin.CNE) annotation (Line(
          points={{62.38,17.8},{30.19,17.8},{30.19,-0.4},{0,-0.4}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(fromFluidVolumes.CNA, vasopressin.CNA) annotation (Line(
          points={{-60.4,-60.2},{-36,-60.2},{-36,73.6},{-5.2,73.6}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(fromNerves.bus, nerves) annotation (Line(
          points={{-75.5,65.9},{-83.65,65.9},{-83.65,66},{-90,66}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(fromCardiovascularSystem.bus, cardiovascular) annotation (Line(
          points={{-75.3,14.1},{-89.55,14.1},{-89.55,12},{-92,12}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(fromFluidVolumes.bus, fluidVolumes) annotation (Line(
          points={{-75.3,-64.3},{-84.65,-64.3},{-84.65,-70},{-90,-70}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(vasopressin.AU, fromNerves.AU) annotation (Line(
          points={{-5.2,70},{-32,70},{-32,65.8},{-58.4,65.8}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(fromCardiovascularSystem.PRA, vasopressin.PRA) annotation (Line(
          points={{-58.9,18.2},{-26.45,18.2},{-26.45,66.4},{-5.2,66.4}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(aldosterone.PA, fromCardiovascularSystem.PA) annotation (Line(
          points={{18.4,-34.2},{-49.8,-34.2},{-49.8,10.1},{-59.1,10.1}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(fromFluidVolumes.CKE, aldosterone.CKE) annotation (Line(
          points={{-60.4,-68.2},{-21.2,-68.2},{-21.2,-37.8},{18.8,-37.8}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(aldosterone.CNA, fromFluidVolumes.CNA) annotation (Line(
          points={{18.6,-41},{10,-42},{-36,-42},{-36,-60.2},{-60.4,-60.2}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(angiotensin.CNA, fromFluidVolumes.CNA) annotation (Line(
          points={{-21.2,3},{-21.2,2},{-36,2},{-36,-60},{-60.4,-60.2}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(fromFluidVolumes.RFN, angiotensin.RFN) annotation (Line(
          points={{-60.4,-64.2},{-52,-64},{-28,-64},{-28,8},{-20.8,8}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(angiotensin.REK, fromCardiovascularSystem.REK) annotation (Line(
          points={{-20.8,10.8},{-40.4,10.8},{-40.4,14.3},{-58.9,14.3}},
          color={0,0,127},
          smooth=Smooth.None));
    end Hormones;

    package Interfaces
      block FromCardiovascularSystem

        Guyton72.CardiovascularSystem.Interfaces.CardiovascularSystemInput bus 
      annotation (extent=[-37,-71; 3,-31], Placement(transformation(extent={{-93,-19},
                  {-53,21}})));
        Modelica.Blocks.Interfaces.RealOutput PRA annotation (extent=[-37,26; 3,66],
            Placement(transformation(extent={{71,22},{111,62}})));
        Modelica.Blocks.Interfaces.RealOutput PA  annotation (extent=[-37,-71; 3,-31], Placement(transformation(extent={{69,-59},
                  {109,-19}})));
        annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                  -100},{100,100}}), graphics));
        Modelica.Blocks.Interfaces.RealOutput REK 
          annotation (extent=[-1,-21; 39,19], Placement(transformation(extent={{71,-17},
                  {111,23}})));
      equation
        PRA = bus.PRA;
        PA = bus.PA;
        REK = bus.REK;
      end FromCardiovascularSystem;

      block FromNerves

        Guyton72.Nerves.Interfaces.NervesInput bus annotation (extent=[-37,-71; 3,-31], Placement(transformation(extent={{-95,-21},
                  {-55,19}})));
        Modelica.Blocks.Interfaces.RealOutput AU annotation (extent=[-20,-20; 20,20],
            Placement(transformation(extent={{76,-22},{116,18}})));
        annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                  -100},{100,100}}), graphics));
      equation
        AU = bus.AU;
      end FromNerves;

      block FromFluidVolumes

        Guyton72.FluidVolumes.Interfaces.FluidVolumesInput bus annotation (extent=[-37,-71; 3,-31], Placement(transformation(extent={{-93,-23},
                  {-53,17}})));
        Modelica.Blocks.Interfaces.RealOutput CNA 
          annotation (extent=[-26,20; 14,60], Placement(transformation(extent={
                  {56,18},{96,58}})));
        annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={
                  {-100,-100},{100,100}}), graphics));
        Modelica.Blocks.Interfaces.RealOutput CKE 
          annotation (extent=[-26,-66; 14,-26], Placement(transformation(extent=
                 {{56,-62},{96,-22}})));
        Modelica.Blocks.Interfaces.RealOutput RFN 
          annotation (extent=[0,-22; 40,18], Placement(transformation(extent={{
                  56,-22},{96,18}})));
      end FromFluidVolumes;

      connector HormonesInput = HormonesBus ( redeclare type RealType = 
              Modelica.Blocks.Interfaces.RealInput) 
      annotation (defaultComponentName="hormones",
        Coordsys(extent=[-100, -100; 100, 100],
          grid=[1,1],
          component=[20,20],
            scale=0.2),
        Icon(coordinateSystem(extent=[-100,-100; 100,100]),
             Polygon(points=[-100,100; 100,0; -100,-100; -100,100], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={127,127,127}))),
        Diagram(Polygon(points=[0,50; 100,0; 0,-50; 0,50], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={127,127,127})),
                                        Text(
            extent=[-120,105; 100,60],
            string="%name",
              style(color=74, rgbcolor={0,0,127}))),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));
      connector HormonesOuput = output HormonesBus 
       annotation (defaultComponentName="hormones",
        Coordsys(extent=[-100, -100; 100, 100],
          grid=[1,1],
          component=[20,20],
            scale=0.2),
        Icon(coordinateSystem(extent=[-100,-100; 100,100]),
             Polygon(points=[-100,100; 100,0; -100,-100; -100,100], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={200,200,200}))),
        Diagram(Polygon(points=[0,50; 100,0; 0,-50; 0,50], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={200,200,200})),
                                        Text(
            extent=[-120,105; 100,60],
            string="%name",
              style(color=74, rgbcolor={0,0,127}))),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));

      connector HormonesBus

          Real AHM "antidiuretic hormone multiplier, ratio of normal effect";
          Real AM "aldosterone multiplier, ratio of normal effect";
          Real ANM "angiotensin multiplier effect on vascular resistence";
          Real CNE
          "sodium concentration abnormality causing third factor effect";
      end HormonesBus;

      block toHormones

       Modelica.Blocks.Interfaces.RealInput ANM annotation (extent=[-37,-71; 3,-31], Placement(transformation(extent={{-49,-73},
                  {-9,-33}})));
       Modelica.Blocks.Interfaces.RealInput AHM annotation (extent=[-37,-71; 3,-31], Placement(transformation(extent={{-47,-39},
                  {-7,1}})));
       Modelica.Blocks.Interfaces.RealInput CNE annotation (extent=[-37,-71; 3,-31], Placement(transformation(extent={{-47,-11},
                  {-7,29}})));
       Modelica.Blocks.Interfaces.RealInput AM annotation (extent=[-37,-71; 3,-31], Placement(transformation(extent={{-47,23},
                  {-7,63}})));
        HormonesOuput hormones annotation (Placement(transformation(extent={{
                  -20,-24},{20,16}}), iconTransformation(extent={{8,-10},{28,10}})));
      equation
       bus.ANM = ANM;
       bus.AHM = AHM;
       bus.AM = AM;
       bus.CNE = CNE;
        annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={
                  {-100,-100},{100,100}}), graphics));
      end toHormones;
    end Interfaces;
  end Hormones;

  annotation (uses(Modelica(version="3.0")));
  package Nerves
    package AutonomicControl
      model AutonimicControl
       extends Modelica.Blocks.Interfaces.BlockIcon;
        Modelica.Blocks.Interfaces.RealInput POT 
          annotation (extent=[-114,64; -74,104]);
        Modelica.Blocks.Interfaces.RealInput PA 
          annotation (extent=[-110,24; -70,64]);
        Modelica.Blocks.Interfaces.RealInput P2O 
          annotation (extent=[-114,-2; -74,38]);
        Modelica.Blocks.Interfaces.RealInput EXC 
          annotation (extent=[-110,-32; -70,8]);
        Modelica.Blocks.Interfaces.RealOutput AU 
          annotation (extent=[82,52; 102,72]);
        Modelica.Blocks.Interfaces.RealOutput VVR 
          annotation (extent=[76,30; 96,50]);
        Modelica.Blocks.Interfaces.RealOutput AUH 
          annotation (extent=[74,10; 94,30]);
        Modelica.Blocks.Interfaces.RealOutput AUM 
          annotation (extent=[76,-10; 96,10]);
        Modelica.Blocks.Interfaces.RealOutput AVE 
          annotation (extent=[80,-40; 100,-20]);
        annotation (Diagram);
      end AutonimicControl;
    end AutonomicControl;

    model Nerves
      extends Modelica.Blocks.Interfaces.BlockIcon;
      AutonomicControl.AutonimicControl autonimicControl 
        annotation (extent=[-6,22; 14,42]);
      Guyton72.Nerves.Interfaces.NervesOuput nerves 
                         annotation (extent=[62,-10; 102,30]);
      Guyton72.CardiovascularSystem.Interfaces.CardiovascularSystemInput
        cardiovascular 
        annotation (extent=[-114,-2; -74,38]);
      Guyton72.Hormones.Interfaces.HormonesInput hormones 
                                      annotation (extent=[-114,44; -74,84]);
    equation

      annotation (Diagram);
      thirstAdnDrinking.AHM = hormones.AHM;

      thirstAdnDrinking.POT = cardiovascular.POT;
      nerves.STH = thirstAdnDrinking.STH;
      nerves.TVD = thirstAdnDrinking.TVD;

      autonimicControl.POT = cardiovascular.POT;
      autonimicControl.PA = cardiovascular.PA;
      autonimicControl.P2O = cardiovascular.P2O;
      autonimicControl.EXC = cardiovascular.EXC;
      nerves.AU = autonimicControl.AU;
      nerves.VVR = autonimicControl.VVR;
      nerves.AUH = autonimicControl.AUH;
      nerves.AUM = autonimicControl.AUM;
      nerves.AVE = autonimicControl.AVE;

    end Nerves;

    package Interfaces
      connector NervesInput = NervesBus (redeclare type RealType = 
              Modelica.Blocks.Interfaces.RealInput) 
      annotation (defaultComponentName="nerves",
        Coordsys(extent=[-100, -100; 100, 100],
          grid=[1,1],
          component=[20,20],
            scale=0.2),
        Icon(coordinateSystem(extent=[-100,-100; 100,100]),
             Polygon(points=[-100,100; 100,0; -100,-100; -100,100], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={0,127,127}))),
        Diagram(Polygon(points=[-100,49; 0,-1; -100,-51; -100,49],
                                                           style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={0,127,127})),
                                        Text(
            extent=[-120,105; 100,60],
            string="%name",
              style(color=74, rgbcolor={0,0,127}))),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));
      connector NervesOuput = output NervesBus annotation (defaultComponentName="nerves",
        Coordsys(extent=[-100, -100; 100, 100],
          grid=[1,1],
          component=[20,20],
            scale=0.2),
        Icon(coordinateSystem(extent=[-100,-100; 100,100]),
             Polygon(points=[-100,100; 100,0; -100,-100; -100,100], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={0,200,200}))),
        Diagram(Polygon(points=[0,50; 100,0; 0,-50; 0,50], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={0,200,200})),
                                        Text(
            extent=[-120,105; 100,60],
            string="%name",
              style(color=74, rgbcolor={0,0,127}))),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));
      connector NervesBus
          replaceable type RealType = Real;
          RealType AU;
          RealType VVR;
          RealType AUH;
          RealType AUM;
          RealType AVE;

          RealType STH;
          RealType TVD;

      end NervesBus;
    end Interfaces;
  end Nerves;

  package FluidVolumes
    package RedCellsAndViscosity
      model RedCellsAndViscosity
        extends Modelica.Blocks.Interfaces.BlockIcon;
        Modelica.Blocks.Interfaces.RealInput POT 
                                               annotation (extent=[-120,30; -80,70]);
        Modelica.Blocks.Interfaces.RealInput VB annotation (extent=[-120,-40; -80,0]);
        Modelica.Blocks.Interfaces.RealOutput VIM 
                                                annotation (extent=[84,40; 104,60]);
        Modelica.Blocks.Interfaces.RealOutput VRC 
                                                 annotation (extent=[84,12; 104,32]);
        Modelica.Blocks.Interfaces.RealOutput HM annotation (extent=[84,-26; 104,-6]);
        annotation (Diagram);
      end RedCellsAndViscosity;
    end RedCellsAndViscosity;

    package TissueFluids_PressureAndGel
      model TissueFluids_PressureAndGel
        extends Modelica.Blocks.Interfaces.BlockIcon;
      end TissueFluids_PressureAndGel;
    end TissueFluids_PressureAndGel;

    package KidneyDynamicsAndExcretion
      model KidneyDynamicsAndExcretion
        extends Modelica.Blocks.Interfaces.BlockIcon;
      end KidneyDynamicsAndExcretion;
    end KidneyDynamicsAndExcretion;

    package ElectrolytesAndCellWater
      model ElectrolytesAndCellWater
        extends Modelica.Blocks.Interfaces.BlockIcon;
        Modelica.Blocks.Interfaces.RealInput AM annotation (extent=[-120,60; -80,100]);
        Modelica.Blocks.Interfaces.RealInput NOD annotation (extent=[-120,34; -80,74]);
        Modelica.Blocks.Interfaces.RealInput REK annotation (extent=[-120,14; -80,54]);
        Modelica.Blocks.Interfaces.RealInput STH annotation (extent=[-120,-8; -80,32]);
        Modelica.Blocks.Interfaces.RealInput VPF annotation (extent=[-120,-34; -80,6]);
        Modelica.Blocks.Interfaces.RealInput VP 
          annotation (extent=[-120,-66; -80,-26]);
        Modelica.Blocks.Interfaces.RealInput VTS 
          annotation (extent=[-120,-100; -80,-60]);
        annotation (Diagram);
        Modelica.Blocks.Interfaces.RealOutput VID annotation (extent=[82,48; 102,68]);
        Modelica.Blocks.Interfaces.RealOutput CNA annotation (extent=[82,22; 102,42]);
        Modelica.Blocks.Interfaces.RealOutput CKE annotation (extent=[82,-8; 102,12]);
        Modelica.Blocks.Interfaces.RealOutput VTW 
          annotation (extent=[82,-44; 102,-24]);
      end ElectrolytesAndCellWater;
    end ElectrolytesAndCellWater;

    model FluidVolumes
      extends Modelica.Blocks.Interfaces.BlockIcon;
      Guyton72.FluidVolumes.Interfaces.FluidVolumesOuput fluidVolumes 
                                     annotation (extent=[60,-16; 100,24]);
      RedCellsAndViscosity.RedCellsAndViscosity redCellsAndViscosity 
        annotation (extent=[-16,62; 4,82]);
      TissueFluids_PressureAndGel.TissueFluids_PressureAndGel
        tissueFluids_PressureAndGel annotation (extent=[-18,18; 2,38]);
      KidneyDynamicsAndExcretion.KidneyDynamicsAndExcretion
        kidneyDynamicsAndExcretion annotation (extent=[-18,-16; 2,4]);
      ElectrolytesAndCellWater.ElectrolytesAndCellWater
        electrolytesAndCellWater 
        annotation (extent=[-18,-52; 2,-32]);
      Guyton72.CardiovascularSystem.Interfaces.CardiovascularSystemInput
        cardiovascular 
        annotation (extent=[-116,42; -76,82]);
      Guyton72.Nerves.Interfaces.NervesInput nerves 
                                annotation (extent=[-116,-2; -76,38]);
      Guyton72.Hormones.Interfaces.HormonesInput hormones 
                                      annotation (extent=[-116,-44; -76,-4]);
      ThirstAndDrinking.ThirstAdnDrinking thirstAdnDrinking 
        annotation (extent=[-18,-90; 2,-70]);
    equation
      redCellsAndViscosity.POT = cardiovascular.POT;
      redCellsAndViscosity.VB = cardiovascular.VB;
      fluidVolumes.VIM = redCellsAndViscosity.VIM;
      fluidVolumes.VRC = redCellsAndViscosity.VRC;
      fluidVolumes.HM = redCellsAndViscosity.HM;

      tissueFluids_PressureAndGel.VTC = cardiovascular.VTC;
      fluidVolumes.VTS = tissueFluids_PressureAndGel.VTS;
      fluidVolumes.PTC = tissueFluids_PressureAndGel.PTC;
      fluidVolumes.VTL = tissueFluids_PressureAndGel.VTL;
      fluidVolumes.CPI = tissueFluids_PressureAndGel.CPI;
      fluidVolumes.DPC = tissueFluids_PressureAndGel.DPC;

      kidneyDynamicsAndExcretion.AUM = nerves.AUM;
      kidneyDynamicsAndExcretion.VM = cardiovascular.VM;
      kidneyDynamicsAndExcretion.PA = cardiovascular.PA;
      kidneyDynamicsAndExcretion.PPC = cardiovascular.PPC;
      kidneyDynamicsAndExcretion.REK = cardiovascular.REK;
      kidneyDynamicsAndExcretion.AHM = hormones.AHM;
      fluidVolumes.RFN = tissueFluids_PressureAndGel.RFN;
      fluidVolumes.NOD = tissueFluids_PressureAndGel.NOD;
      fluidVolumes.VUD = tissueFluids_PressureAndGel.VUD;

      electrolytesAndCellWater.AM = hormones.AM;
      electrolytesAndCellWater.REK = cardiovascular.REK;
      electrolytesAndCellWater.STH = nerves.STH;
      electrolytesAndCellWater.VPF = cardiovascular.VPF;
      electrolytesAndCellWater.VP = cardiovascular.VP;
      fluidVolumes.VID = tissueFluids_PressureAndGel.VID;
      fluidVolumes.CNA = tissueFluids_PressureAndGel.CNA;
      fluidVolumes.CKE = tissueFluids_PressureAndGel.CKE;
      fluidVolumes.VTW = tissueFluids_PressureAndGel.VTW;
    end FluidVolumes;

    package ThirstAndDrinking
      model ThirstAdnDrinking
        extends Modelica.Blocks.Interfaces.BlockIcon;
        Modelica.Blocks.Interfaces.RealInput AHM 
          annotation (extent=[-118,42; -78,82]);
        Modelica.Blocks.Interfaces.RealInput POT 
          annotation (extent=[-118,-38; -78,2]);
        Modelica.Blocks.Interfaces.RealOutput STH 
          annotation (extent=[80,50; 100,70]);
        Modelica.Blocks.Interfaces.RealOutput TVD 
          annotation (extent=[80,-38; 100,-18]);
        annotation (Diagram);
      end ThirstAdnDrinking;
    end ThirstAndDrinking;

    package Interfaces
      connector FluidVolumesInput = FluidVolumesBus (redeclare type RealType = 
              Modelica.Blocks.Interfaces.RealInput)                                                                   annotation (defaultComponentName="fluidVolumes",
        Coordsys(extent=[-100, -100; 100, 100],
          grid=[1,1],
          component=[20,20],
            scale=0.2),
        Icon(coordinateSystem(extent=[-100,-100; 100,100]),
             Polygon(points=[-100,100; 100,0; -100,-100; -100,100], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={127,0,127}))),
        Diagram(Polygon(points=[-100,48; 0,-2; -100,-52; -100,48],
                                                           style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={127,0,127})),
                                        Text(
            extent=[-120,105; 100,60],
            string="%name",
              style(color=74, rgbcolor={0,0,127}))),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));
      connector FluidVolumesOuput = output FluidVolumesBus annotation (defaultComponentName="fluidVolumes",
        Coordsys(extent=[-100, -100; 100, 100],
          grid=[1,1],
          component=[20,20],
            scale=0.2),
        Icon(coordinateSystem(extent=[-100,-100; 100,100]),
             Polygon(points=[-100,100; 100,0; -100,-100; -100,100], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={200,0,200}))),
        Diagram(Polygon(points=[0,50; 100,0; 0,-50; 0,50], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={200,0,200})),
                                        Text(
            extent=[-120,105; 100,60],
            string="%name",
              style(color=74, rgbcolor={0,0,127}))),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));
      connector FluidVolumesBus
         replaceable type RealType = Real;
         RealType VIM;
         RealType VRC;
         RealType HM;

         RealType VTS;
         RealType PTC;
         RealType VTL;
         RealType CPI;
         RealType DPC;

         RealType RFN "renal blood flow if kidney is not damaged";
         RealType NOD;
         RealType VUD;

         RealType VID;
         RealType CNA;
         RealType CKE;
         RealType VTW;

      end FluidVolumesBus;
    end Interfaces;
  end FluidVolumes;

  package CardiovascularSystem
    package BloodResistances
      package NonmuscleLocalBloodFlowControl       
      end NonmuscleLocalBloodFlowControl;

      package MuscleBloodFlowControlAndPO2       
      end MuscleBloodFlowControlAndPO2;

      package VascularStressRelaxation       
      end VascularStressRelaxation;

      package PulmonaryDynamicsAndFluids       
      end PulmonaryDynamicsAndFluids;

      package CapilaryMembraneDynamics       
      end CapilaryMembraneDynamics;
    end BloodResistances;

    package BloodDeliveries
      package NonmuscleOxigenDelivery       
      end NonmuscleOxigenDelivery;
    end BloodDeliveries;

    package HeartRateAndStrokeVolume     
    end HeartRateAndStrokeVolume;

    package HeartHypertrophyOrDeterioration     
    end HeartHypertrophyOrDeterioration;

    model CardiovascularSystem
      extends Modelica.Blocks.Interfaces.BlockIcon;
      Guyton72.CardiovascularSystem.Interfaces.CardiovascularSystemOuput
        cardiovascular 
        annotation (extent=[60,-16; 100,24]);
      Guyton72.FluidVolumes.Interfaces.FluidVolumesInput fluidVolumes 
        annotation (extent=[-120,-10; -80,30]);
      Guyton72.Hormones.Interfaces.HormonesInput hormones 
                                      annotation (extent=[-120,34; -80,74]);
      Guyton72.Nerves.Interfaces.NervesInput nerves 
                                annotation (extent=[-120,-56; -80,-16]);
    end CardiovascularSystem;

    package Interfaces
      connector CardiovascularSystemInput =  input CardiovascularSystemBus                                                                                      annotation (defaultComponentName="cardiovascular",
        Coordsys(extent=[-100, -100; 100, 100],
          grid=[1,1],
          component=[20,20],
            scale=0.2),
        Icon(coordinateSystem(extent=[-100,-100; 100,100]),
             Polygon(points=[-100,100; 100,0; -100,-100; -100,100], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={127,0,0}))),
        Diagram(Polygon(points=[-100,49; 0,-1; -100,-51; -100,49],
                                                           style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={127,0,0})),
                                        Text(
            extent=[-120,105; 100,60],
            string="%name",
              style(color=74, rgbcolor={0,0,127}))),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));
      connector CardiovascularSystemOuput = output CardiovascularSystemBus annotation (defaultComponentName="cardiovascular",
        Coordsys(extent=[-100, -100; 100, 100],
          grid=[1,1],
          component=[20,20],
            scale=0.2),
        Icon(coordinateSystem(extent=[-100,-100; 100,100]),
             Polygon(points=[-100,100; 100,0; -100,-100; -100,100], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={200,0,0}))),
        Diagram(Polygon(points=[0,50; 100,0; 0,-50; 0,50], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=74,
                rgbfillColor={200,0,0})),
                                        Text(
            extent=[-120,105; 100,60],
            string="%name",
              style(color=74, rgbcolor={0,0,127}))),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));
      connector CardiovascularSystemBus

          Real VVE;
          Real POT;
          Real PA;
          Real P2O;
          Real EXC;

          Real VB;
          Real VTC;
          Real VPF;
          Real VP;
          Real VM;

          Real REK;
          Real PPC;
          Real PRA;

      end CardiovascularSystemBus;
    end Interfaces;
  end CardiovascularSystem;

  model Guyton1972
    Hormones.Hormones hormones annotation (extent=[-40,12; -20,32]);
    Nerves.Nerves nerves annotation (extent=[34,-36; 54,-16]);
    FluidVolumes.FluidVolumes fluidVolumes 
      annotation (extent=[-46,-36; -26,-16]);
    CardiovascularSystem.CardiovascularSystem cardiovascularSystem 
      annotation (extent=[-6,-36; 14,-16]);
    annotation (Diagram);
  equation
    connect(cardiovascularSystem.cardiovascular, nerves.cardiovascular) 
      annotation (points=[12,-25.6; 24,-25.6; 24,-24.2; 34.6,-24.2], style(
          color=74, rgbcolor={0,0,127}));
    connect(cardiovascularSystem.cardiovascular, fluidVolumes.cardiovascular) 
      annotation (points=[12,-25.6; 24,-25.6; 24,40; -60,40; -60,-19.8; -45.6,
          -19.8], style(color=74, rgbcolor={0,0,127}));
    connect(fluidVolumes.fluidVolumes, cardiovascularSystem.fluidVolumes) 
      annotation (points=[-28,-25.6; -18,-25.6; -18,-25; -6,-25], style(color=
            74, rgbcolor={0,0,127}));
    connect(hormones.hormones, cardiovascularSystem.hormones) annotation (
        points=[-22,23; -14,23; -14,-20.6; -6,-20.6], style(color=74, rgbcolor=
            {0,0,127}));
    connect(fluidVolumes.hormones, hormones.hormones) annotation (points=[-45.6,
          -28.4; -52,-28.4; -52,4; -14,4; -14,23; -22,23], style(color=74,
          rgbcolor={0,0,127}));
    connect(nerves.nerves, cardiovascularSystem.nerves) annotation (points=[
          52.2,-25; 66,-25; 66,-42; -12,-42; -12,-29.6; -6,-29.6], style(color=
            74, rgbcolor={0,0,127}));
    connect(fluidVolumes.nerves, nerves.nerves) annotation (points=[-45.6,-24.2;
          -50,-24.2; -50,-42; 66,-42; 66,-25; 52.2,-25], style(color=74,
          rgbcolor={0,0,127}));
    connect(hormones.hormones, nerves.hormones) annotation (points=[-22,23; 18,
          23; 18,-19.6; 34.6,-19.6], style(color=74, rgbcolor={0,0,127}));
    connect(nerves.nerves, hormones.nervesInput) annotation (points=[52.2,-25;
          66,-25; 66,38; -46,38; -46,27.4; -38,27.4], style(color=74, rgbcolor=
            {0,0,127}));
    connect(hormones.cardiovascularSystemInput, cardiovascularSystem.cardiovascular) 
      annotation (points=[-38,23; -60,23; -60,40; 24,40; 24,-25.6; 12,-25.6],
        style(color=3, rgbcolor={0,0,255}));
    connect(hormones.fluidVolumesInput, fluidVolumes.fluidVolumes) annotation (
        points=[-38,17.4; -42,17.4; -42,-4; -24,-4; -24,-25.6; -28,-25.6],
        style(color=3, rgbcolor={0,0,255}));
  end Guyton1972;

end Guyton72;
